# homeeasylib
This library contains custom implementation of the protocol used by Home Easy application to communicate with compatible HVAC units

[Hass.io](https://home-assistant.io/) integration coming soon.

Original Home Easy application:
- Android [Home Easy](https://play.google.com/store/apps/details?id=net.conditioner.web)
- iOS [Home Easy](https://itunes.apple.com/cn/app/home-easy/id1263076928?mt=8)

List of compatible HVAC units:
- Cooper&Hunter Nordic Premium CH-S09FTXN-PW

## License

This project is licensed under the GNU GPLv3 - see the [LICENSE](LICENSE) file for details

## Acknowledgments

- Inspired by [cooper_hunter-hvac-mqtt-bridge](https://github.com/T-REX-XP/cooper_hunter-hvac-mqtt-bridge) project by [T-REX-XP](https://github.com/T-REX-XP)
and [Arthur Krupa](https://github.com/arthurkrupa).
